<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/default_dune_plugin.php';
require_once 'lib/default_archive.php';
require_once 'lib/action_factory.php';
require_once 'lib/control_factory.php';
require_once 'lib/dune_exception.php';
require_once 'lib/utils.php';
require_once 'lib/abstract_preloaded_regular_screen.php';
require_once 'lib/vod/vod_list_screen.php';
require_once 'lib/vod/vod_search_screen.php';
require_once 'lib/vod/vod_genres_screen.php';
require_once 'lib/vod/vod_movie_screen.php';
require_once 'lib/vod/vod_series_list_screen.php';
require_once 'lib/vod/vod_favorites_screen.php';

require_once 'lib/tv/tv_group_list_screen.php';
require_once 'lib/tv/tv_channel_list_screen.php';
require_once 'lib/tv/tv_favorites_screen.php';

require_once 'Rodnoe_exception.php';
require_once 'Rodnoe_config.php';
require_once 'Rodnoe_entry_handler.php';
require_once 'Rodnoe_api.php';
require_once 'Rodnoe_tv.php';
require_once 'Rodnoe_tv_group_list_screen.php';
require_once 'Rodnoe_setup_screen.php';
require_once 'Rodnoe_vod.php';
require_once 'Rodnoe_vod_root_screen.php';
require_once 'Rodnoe_vod_list_screen.php';


///////////////////////////////////////////////////////////////////////////

class RodnoePlugin extends DefaultDunePlugin
{
    private $session;
    private $entry_handler;

    public function __construct()
    {
        $this->session = new RodnoeApi($this);
        $this->entry_handler = new RodnoeEntryHandler($this->session);
        $this->tv = new RodnoeTv($this->session);
        $this->vod = new RodnoeVod($this->session);

        $tv_folder_views = $this->get_tv_folder_views();

        $this->add_screen(new RodnoeSetupScreen($this->session));

        $this->add_screen(new RodnoeTvGroupListScreen($this->tv,
            RodnoeConfig::GET_TV_GROUP_LIST_FOLDER_VIEWS(), $this->session));
        $this->add_screen(new TvChannelListScreen($this->tv,
            RodnoeConfig::GET_TV_CHANNEL_LIST_FOLDER_VIEWS()));
        $this->add_screen(new TvFavoritesScreen($this->tv,
            RodnoeConfig::GET_TV_CHANNEL_LIST_FOLDER_VIEWS()));

        $this->add_screen(
            new RodnoeVodRootScreen($this->session, $tv_folder_views));

        $this->add_screen(
            new RodnoeVodListScreen($this->session, $this->vod));

        $this->add_screen(new VodMovieScreen($this->vod));

        $this->add_screen(new VodSeriesListScreen($this->vod));

        $this->add_screen(new VodFavoritesScreen($this->vod));

        $this->add_screen(new VodSearchScreen($this->vod));

        $this->add_screen(new VodGenresScreen($this->vod));

    }

    ///////////////////////////////////////////////////////////////////////

    public function unset_login()
    {
        $this->session->unset_login();
        $this->tv->unload_channels();
        $this->vod->clear_movie_cache();
        $this->vod->clear_genre_cache();

        DefaultArchive::clear_cache();
    }

    ///////////////////////////////////////////////////////////////////////

    private function get_tv_folder_views()
    {
        return RodnoeConfig::GET_TV_GROUP_LIST_FOLDER_VIEWS();
    }
   
}

///////////////////////////////////////////////////////////////////////////
?>
